<?xml version="1.0" encoding="utf-8"?>
<?mso-application progid="Excel.Sheet"?>
<xsl:stylesheet	version="3.3" 
				xmlns="urn:schemas-microsoft-com:office:spreadsheet"
				xmlns:html="http://www.w3.org/TR/REC-html40"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:o="urn:schemas-microsoft-com:office:office"
				xmlns:x="urn:schemas-microsoft-com:office:excel"
				xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
				exclude-result-prefixes="xs">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="no"/>
	
	<xsl:template name='Comment'>
		<xsl:comment>
			PROMAX ELECTRONICA SL 
			Version: Complete_Coverage_Stylesheet 3.3
			Marc Travé 09/09/2013
			
			This file is a transformation file for a XML data file in order to give a Style when opening
			the XML data file using Microsoft Excel document.
			
			This style will provide a table format compatible with online converters to KML file format
		</xsl:comment>
	</xsl:template>

	<!-- 1.0 MAIN DISTRIBUTION CODE -->
	<xsl:template match='/' priority="1">
		<xsl:call-template name='Initial_Comment_template'/>
		<xsl:choose>
			<xsl:when test="COVERAGE">
				<xsl:call-template name='Version_Control_template'/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name='Error_Workbook_template'>
					<xsl:with-param name="error_code" select="'001'"/>
					<xsl:with-param name="text" select="'The main node does not match with the XSL main path.'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name='Version_Control_template'>
		<xsl:choose>
			<xsl:when test="$Coverage_xsl_version >= $Coverage_xml_version">
				<xsl:call-template name='Coverage_GE_template'/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name='Error_Workbook_template'>
					<xsl:with-param name="error_code" select="'002'"/>
					<xsl:with-param name="text">XSL version is not the actual one. Your actual COVERAGE.XML file version is <xsl:value-of 
						select="$Coverage_xml_version"/> and your COVERAGE.XSL file version is <xsl:value-of select="$Coverage_xsl_version"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- 2.0 CODE TEMPLATES -->
	<xsl:template name='Initial_Comment_template'>
		<xsl:comment>
			PROMAX ELECTRONICA SL 
			Version: Coverage 3.3
			Marc Travé 09/09/2013
			
			This file is the result of a transformation process using XSLT in order to obtain a XML file with
			DATA+Stylesheet information from an especific XML only Data file provided by functionalities of
			a RANGER family equipment
		</xsl:comment>
	</xsl:template>
	
	<xsl:template name='Coverage_GE_template'>
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<Worksheet ss:Name="Google Earth Format">
				<Table>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="50"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="200"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="45"/>
					<xsl:call-template name='google_earth_table_format_template'/>
				</Table>
			</Worksheet>
        </Workbook>
	</xsl:template>
	
	<!-- 2.1 STRUCTURE TEMPLATES -->		
	<xsl:template name='google_earth_table_format_template'>
		<xsl:call-template name='google_earth_table_heading_template'/>
		<xsl:call-template name='google_earth_first_row_table_data_template'>
			<xsl:with-param name="cell_position" select="1"/>
		</xsl:call-template>
		<xsl:for-each select="COVERAGE/CPOINT">
			<xsl:if test="position()!=1">
				<xsl:call-template name='google_earth_table_data_template'>
					<xsl:with-param name="cell_position" select="1"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='google_earth_table_heading_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Latitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Longitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Name</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Description</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Icon</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='google_earth_first_row_table_data_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/GPS/@latitude"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/GPS/@longitude"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/@id"/></Data>
			</Cell>
 			<xsl:if test="$signal_type = 'DVB-T2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'DVB-T'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<!-- SFC: -->
			<xsl:if test="$signal_type = 'DVB-C'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'DVB-C2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:if test="$signal_type = 'DAB'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>	
			<xsl:if test="$signal_type = 'DVB-S'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-S2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ISDB-T'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>	
			<xsl:if test="$signal_type = 'ATSC'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'ANALOG'">
				<xsl:call-template name='google_earth_ANALOG_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<!-- SFC: -->
 			<xsl:if test="$signal_type = 'FM'">
				<xsl:call-template name='google_earth_FM_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<xsl:if test="$signal_type = 'ERROR'">
				<xsl:call-template name='Error_Cell_template'>
					<xsl:with-param name="error_code" select="'006'"/>
					<xsl:with-param name="text" select="'There is no match between Sygnal type node and this XSD tempataes list.'"/>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<Cell ss:Index="{$cell_position+4}" ss:StyleID="s23">
				<Data ss:Type="Number">55</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>

	<!-- SFC: -->	

	<xsl:template name='google_earth_ANALOG_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units"/>   CN: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/CN/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/CN/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	<!-- SFC: -->
	
	<xsl:template name='google_earth_FM_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units"/>    FM Deviation: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@units"/></Data>
		</Cell>
	</xsl:template>

	<xsl:template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<!-- SFC: -->
	<xsl:template name='google_earth_ANALOG_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="MEASURES/LEVEL/@value"/>
				<xsl:value-of select="MEASURES/LEVEL/@units"/>   CN: <xsl:value-of 
				select="MEASURES/CN/@value"/>
				<xsl:value-of select="MEASURES/CN/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	<!-- SFC: -->
	
	<xsl:template name='google_earth_FM_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="MEASURES/LEVEL/@value"/>
				<xsl:value-of select="MEASURES/LEVEL/@units"/>    FM Deviation: <xsl:value-of 
				select="MEASURES/FMDEVIATION/@value"/>
				<xsl:value-of select="MEASURES/FMDEVIATION/@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='google_earth_table_data_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<xsl:for-each select="GPS">
				<xsl:call-template name='google_earth_gps_table_template'>
					<xsl:with-param name="cell_position" select="1"/>
				</xsl:call-template>
			</xsl:for-each>
			<Cell ss:Index="{$cell_position+2}"  ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="@id"/></Data>
			</Cell>
			<xsl:if test="$signal_type = 'DVB-T2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'DVB-T'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<!-- SFC: -->
			<xsl:if test="$signal_type = 'DVB-C'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-C2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:if test="$signal_type = 'DAB'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-S'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'DVB-S2'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ISDB-T'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ATSC'">
				<xsl:call-template name='google_earth_DVB_T_T2_C_C2_S_S2_DAB_ISDBT_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'ANALOG'">
				<xsl:call-template name='google_earth_ANALOG_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<!-- SFC: -->
 			<xsl:if test="$signal_type = 'FM'">
				<xsl:call-template name='google_earth_FM_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<xsl:if test="$signal_type = 'ERROR'">
				<xsl:call-template name='Error_Cell_template'>
					<xsl:with-param name="error_code" select="'007'"/>
					<xsl:with-param name="text" select="'There is no match between Signal type node and this XSD templates list.'"/>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<Cell ss:Index="{$cell_position+4}"  ss:StyleID="s23">
				<xsl:if test="position()=last()">
					<Data ss:Type="Number">55</Data>
				</xsl:if>
				<xsl:if test="position()!=last()">
					<Data ss:Type="Number">121</Data>
				</xsl:if>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name="google_earth_gps_table_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@latitude"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@longitude"/></Data>
		</Cell>
	</xsl:template>
	
	<!-- 3.0 GENERIC USEFUL TEMPLATES -->		
	<xsl:template name='Error_Workbook_template'>
		<xsl:param name="error_code"/>
		<xsl:param name="text"/>
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<Worksheet ss:Name="Error Message">
				<Table>
					<Row ss:Index="2" ss:AutoFitHeight="1">
						<Cell ss:Index="2" ss:StyleID="s20">
							<Data ss:Type="String">
								<xsl:value-of select="$Error_Code_text"/><xsl:value-of select="$error_code"/> - <xsl:value-of select="$text"/>
							</Data>
						</Cell>
					</Row>
				</Table>
			</Worksheet>
        </Workbook>
	</xsl:template>
		
	<xsl:template name='Error_Cell_template'>
		<xsl:param name="error_code"/>
		<xsl:param name="text"/>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">
					<xsl:value-of select="$Error_Code_text"/><xsl:value-of select="$error_code"/> - <xsl:value-of select="$text"/>
				</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='Blank_Workbook_template'>
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<Worksheet ss:Name="Sheet 1">
				<Table/>
			</Worksheet>
			<xsl:call-template name='Additional_blank_sheet_template'/>
        </Workbook>
	</xsl:template>
	
	<xsl:template name='Additional_blank_sheet_template'>
		<Worksheet ss:Name="Sheet 2">
			<Table/>
		</Worksheet>
		<Worksheet ss:Name="Sheet 3">
			<Table/>
		</Worksheet>
	</xsl:template>
	
	<xsl:template name="units_range_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_units_range_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23" >
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="scientific_number_value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s33">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_range_value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_units_range_value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_nl_template">	
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<!-- 4.0 GENERIC VARIABLES -->
	<xsl:variable name="Coverage_xsl_version" as="xs:string" select="'3.0'" />

	<xsl:variable name="Coverage_xml_version" as="xs:string">
		<xsl:value-of select="COVERAGE/@version" />
	</xsl:variable>
	
	<xsl:variable name="power_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units" />
	</xsl:variable>
	
	<xsl:variable name="level_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units" />
	</xsl:variable>
	
	<xsl:variable name="fm_deviation_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@units" />
	</xsl:variable>
	
	<xsl:variable name="cn_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/CN/@units" />
	</xsl:variable>  
	
	<xsl:variable name="mer_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units" />
	</xsl:variable>  

	<!-- SFC: -->
	<xsl:variable name="cber_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/CBER/@units" />
	</xsl:variable>
	<!-- SFC: -->
	
	<xsl:variable name="Error_Code_text" select="'Error Code: '" />
	<xsl:variable name="power_label" select="'Power '" /> 
	<xsl:variable name="level_label" select="'Level '" />
	<xsl:variable name="fm_deviation_label" select="'FM deviation '" />
	<xsl:variable name="cn_label" select="'CN '" /> 
	<xsl:variable name="mer_label" select="'MER '" /> 
	<!-- SFC: -->
	<xsl:variable name="cber_label" select="'CBER '" /> 
	<!-- SFC: -->
	<xsl:variable name="open_label" select="' ('" />
	<xsl:variable name="close_label" select="')'" />
	
	<xsl:variable name="signal_type" as="xs:string">
		<xsl:for-each select="COVERAGE/INFORMATION/CHANNEL/MEASUREMENTS">
			<xsl:choose>
				<xsl:when test="DVB-T2">DVB-T2</xsl:when>
				<xsl:when test="DVB-T">DVB-T</xsl:when>
				<!-- SFC: -->
				<xsl:when test="DVB-C">DVB-C</xsl:when> 
				<xsl:when test="DVB-C2">DVB-C2</xsl:when>
				<xsl:when test="DAB">DAB</xsl:when> 
				<xsl:when test="DVB-S">DVB-S</xsl:when>
				<xsl:when test="DVB-S2">DVB-S2</xsl:when>
				<xsl:when test="ANALOG">ANALOG</xsl:when>
				<xsl:when test="ISDB-T">ISDB-T</xsl:when>
				<xsl:when test="ATSC">ATSC</xsl:when>
				<!-- SFC: -->
				<xsl:when test="FM">FM</xsl:when>
				<xsl:otherwise>ERROR</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:variable>
	
	<!-- 5.0 STYLES -->
	<xsl:template name='Styles_template'>
		<Styles>
			<Style ss:ID="Default" ss:Name="Normal">
				<Alignment ss:Vertical="Bottom" ss:Horizontal="Left"/>
				<Borders />
				<Font />
				<Interior />
				<NumberFormat />
				<Protection />
			</Style>
			<Style ss:ID="s20">
				<Font ss:Size="12" ss:Bold="1" />
			</Style>
			<Style ss:ID="s30">
				<Font ss:Size="12" ss:Bold="1" />
				<NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s21">
				<Font ss:Size="12" ss:Bold="1" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="2"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			</Style>
			<Style ss:ID="s31">
				<Font ss:Size="12" ss:Bold="1" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="2"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			   <NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s22">
				<Font ss:Size="12" ss:Bold="0" ss:Color="#0000FF"/>
			</Style>
			<Style ss:ID="s32">
				<Font ss:Size="12" ss:Bold="0" ss:Color="#0000FF"/>
				<NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s23">
				<Font ss:Size="12" ss:Bold="0" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			</Style>
			<Style ss:ID="s33">
				<Font ss:Size="12" ss:Bold="0" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			   <NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s24">
				<Font ss:Size="12" ss:Bold="0" />
			</Style>
			<Style ss:ID="s34">
				<Font ss:Size="12" ss:Bold="0" />
				<NumberFormat ss:Format="Scientific"/>
			</Style>
		</Styles>
	</xsl:template>
	
</xsl:stylesheet>